@@ -1,5 +1,5 @@
 
-# $Id: NATO.pm,v 1.7 2008/09/07 03:23:37 Martin Exp $
+# $Id: NATO.pm,v 1.8 2010-12-02 23:36:28 Martin Exp $
 
 =head1 NAME
 
@@ -27,7 +27,7 @@ This software is released under the same license as Perl itself.
 
 =head1 AUTHOR
 
-Martin Thurn (mthurn@cpan.org).
+Martin 'Kingpin' Thurn, C<mthurn at cpan.org>, L<http://tinyurl.com/nn67z>.
 
 =cut
 
@@ -40,7 +40,7 @@ use warnings;
 
 use base 'Lingua::Alphabet::Phonetic';
 our
-$VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/o);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/o);
 
 my @asAlphabet = qw(
 Alpha Bravo Charlie Delta Echo Foxtrot Golf Hotel India Juliet Kilo Lima
